package cn.wisenergy.chnmuseum.party.model;

import com.baomidou.mybatisplus.annotation.TableName;
import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.Version;
import com.baomidou.mybatisplus.annotation.TableId;
import java.time.LocalDateTime;
import com.baomidou.mybatisplus.annotation.FieldFill;
import com.baomidou.mybatisplus.annotation.TableField;
import java.io.Serializable;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import lombok.AllArgsConstructor;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import cn.wisenergy.chnmuseum.party.common.validator.groups.Add;
import cn.wisenergy.chnmuseum.party.common.validator.groups.Update;
import com.baomidou.mybatisplus.annotation.TableField;

/**
 * <p>
 * 学习内容信息
 * </p>
 *
 * @author Danny Lee
 * @since 2021-03-26
 */
@Data
@Builder
@AllArgsConstructor
@NoArgsConstructor
@Accessors(chain = true)
@EqualsAndHashCode(callSuper = false)
@TableName("t_audit")
@ApiModel(value = "学习内容信息", description = "学习内容信息")
public class Audit implements Serializable {

    private static final long serialVersionUID = 1L;

    @ApiModelProperty("id")
    @TableId(value = "id", type = IdType.ASSIGN_ID)
    @NotNull(message = "id不能为空", groups = {Update.class})
    private String id;

    @ApiModelProperty("审核内容")
    @TableField("audit_content")
    private String auditContent;
    
    @ApiModelProperty("所属机构id")
    @TableField("organ_id")
    private String organId;
    
    @ApiModelProperty("关联表id")
    @TableField("rel_id")
    private String relId;
    
    @ApiModelProperty("提交人员")
    @TableField("user_id")
        @NotBlank(message = "提交人员不能为空", groups = {Add.class})
        private String userId;
    
    @ApiModelProperty("0,看板；1 视频；2 学习内容；3 账号禁用")
    @NotNull(message = "type不能为空", groups = {Update.class})
    @TableField("type")
    private Integer type;
    
    @ApiModelProperty("0 新增；1 修改；2 删除;3 禁用")
    @TableField("item")
    private Integer item;
    
    @ApiModelProperty("1待初审 2 驳回 3 待复审 4通过")
    @NotNull(message = "type不能为空", groups = {Update.class})
    @TableField("status")
    private Integer status;
    
    @ApiModelProperty("创建时间")
    @TableField(value = "create_time", fill = FieldFill.INSERT)
        @NotNull(message = "创建时间不能为空", groups = {Add.class})
        private LocalDateTime createTime;
    
    @ApiModelProperty("0：未删除，1：已删除")
    @TableField("is_deleted")
    private Boolean isDeleted;
    
    @ApiModelProperty("备注")
    @TableField("remarks")
    private String remarks;
    
    @ApiModelProperty("层级 1.初审 2.复审")
    @TableField("level")
    private Integer level;


    @ApiModelProperty("机构名")
    @TableField(exist = false)
    private String orgName;


    @ApiModelProperty("提交人名")
    @TableField(exist = false)
    private String userName;


}
